Re: [ovs-dev] [PATCH] ovn: Rename "gateway" to "l3gateway".

2016-07-28 Thread Russell Bryant
On Thu, Jul 28, 2016 at 9:45 AM, Guru Shetty  wrote:

> On 26 July 2016 at 13:49, Russell Bryant  wrote:
>
>> When L3 gateway support was added, it introduced a port type called
>> "gateway" and a corresponding option called "gateway-chassis".  Since
>> that time, we also have an L2 gateway port type called "l2gateway" and a
>> corresponding option called "l2gateway-chassis".  This patch renames the
>> L3 gateway port type and option to "l3gateway" and "l3gateway-chassis"
>> to make things a little more clear and consistent.
>>
>> Signed-off-by: Russell Bryant 
>>
> Acked-by: Gurucharan Shetty 
>

Thanks, I applied this to master.

I forgot to add the Acks, though.  Sorry about that ...

-- 
Russell Bryant
___
dev mailing list
dev@openvswitch.org
http://openvswitch.org/mailman/listinfo/dev


Re: [ovs-dev] [PATCH] ovn: Rename "gateway" to "l3gateway".

2016-07-28 Thread Guru Shetty
On 26 July 2016 at 13:49, Russell Bryant  wrote:

> When L3 gateway support was added, it introduced a port type called
> "gateway" and a corresponding option called "gateway-chassis".  Since
> that time, we also have an L2 gateway port type called "l2gateway" and a
> corresponding option called "l2gateway-chassis".  This patch renames the
> L3 gateway port type and option to "l3gateway" and "l3gateway-chassis"
> to make things a little more clear and consistent.
>
> Signed-off-by: Russell Bryant 
>
Acked-by: Gurucharan Shetty 


> ---
>  ovn/controller/binding.c |  2 +-
>  ovn/controller/patch.c   |  4 ++--
>  ovn/northd/ovn-northd.c  | 12 ++--
>  ovn/ovn-sb.xml   | 18 +-
>  4 files changed, 18 insertions(+), 18 deletions(-)
>
> diff --git a/ovn/controller/binding.c b/ovn/controller/binding.c
> index e83c1d5..78ebec4 100644
> --- a/ovn/controller/binding.c
> +++ b/ovn/controller/binding.c
> @@ -219,7 +219,7 @@ consider_local_datapath(struct controller_ctx *ctx,
>  add_local_datapath(local_datapaths, binding_rec);
>  }
>  } else if (chassis_rec && binding_rec->chassis == chassis_rec
> -   && strcmp(binding_rec->type, "gateway")) {
> +   && strcmp(binding_rec->type, "l3gateway")) {
>  if (ctx->ovnsb_idl_txn) {
>  VLOG_INFO("Releasing lport %s from this chassis.",
>binding_rec->logical_port);
> diff --git a/ovn/controller/patch.c b/ovn/controller/patch.c
> index 707d08b..012e6ba 100644
> --- a/ovn/controller/patch.c
> +++ b/ovn/controller/patch.c
> @@ -346,9 +346,9 @@ add_logical_patch_ports(struct controller_ctx *ctx,
>  const struct sbrec_port_binding *binding;
>  SBREC_PORT_BINDING_FOR_EACH (binding, ctx->ovnsb_idl) {
>  bool local_port = false;
> -if (!strcmp(binding->type, "gateway")) {
> +if (!strcmp(binding->type, "l3gateway")) {
>  const char *chassis = smap_get(>options,
> -   "gateway-chassis");
> +   "l3gateway-chassis");
>  if (chassis && !strcmp(local_chassis_id, chassis)) {
>  local_port = true;
>  }
> diff --git a/ovn/northd/ovn-northd.c b/ovn/northd/ovn-northd.c
> index 38a3d30..7f5927e 100644
> --- a/ovn/northd/ovn-northd.c
> +++ b/ovn/northd/ovn-northd.c
> @@ -770,10 +770,10 @@ ovn_port_update_sbrec(const struct ovn_port *op)
>  sbrec_port_binding_set_datapath(op->sb, op->od->sb);
>  if (op->nbrp) {
>  /* If the router is for l3 gateway, it resides on a chassis
> - * and its port type is "gateway". */
> + * and its port type is "l3gateway". */
>  const char *chassis = smap_get(>od->nbr->options, "chassis");
>  if (chassis) {
> -sbrec_port_binding_set_type(op->sb, "gateway");
> +sbrec_port_binding_set_type(op->sb, "l3gateway");
>  } else {
>  sbrec_port_binding_set_type(op->sb, "patch");
>  }
> @@ -783,7 +783,7 @@ ovn_port_update_sbrec(const struct ovn_port *op)
>  smap_init();
>  smap_add(, "peer", peer);
>  if (chassis) {
> -smap_add(, "gateway-chassis", chassis);
> +smap_add(, "l3gateway-chassis", chassis);
>  }
>  sbrec_port_binding_set_options(op->sb, );
>  smap_destroy();
> @@ -802,9 +802,9 @@ ovn_port_update_sbrec(const struct ovn_port *op)
>  }
>
>  /* A switch port connected to a gateway router is also of
> - * type "gateway". */
> + * type "l3gateway". */
>  if (chassis) {
> -sbrec_port_binding_set_type(op->sb, "gateway");
> +sbrec_port_binding_set_type(op->sb, "l3gateway");
>  } else {
>  sbrec_port_binding_set_type(op->sb, "patch");
>  }
> @@ -818,7 +818,7 @@ ovn_port_update_sbrec(const struct ovn_port *op)
>  smap_init();
>  smap_add(, "peer", router_port);
>  if (chassis) {
> -smap_add(, "gateway-chassis", chassis);
> +smap_add(, "l3gateway-chassis", chassis);
>  }
>  sbrec_port_binding_set_options(op->sb, );
>  smap_destroy();
> diff --git a/ovn/ovn-sb.xml b/ovn/ovn-sb.xml
> index 3d26e65..3cdf91b 100644
> --- a/ovn/ovn-sb.xml
> +++ b/ovn/ovn-sb.xml
> @@ -1420,8 +1420,8 @@ tcp.flags = RST;
>database, which identifies logical ports via the conventions
> described
>in IntegrationGuide.md.  (The exceptions are for
>Port_Binding records with type of
> -  gateway, whose locations are identified by
> -  ovn-northd via the options:gateway-chassis
> +  l3gateway, whose locations are identified by
> +  ovn-northd via the
> options:l3gateway-chassis
>column in this table.  ovn-controller is still
> 

Re: [ovs-dev] [PATCH] ovn: Rename "gateway" to "l3gateway".

2016-07-27 Thread Russell Bryant
On Tue, Jul 26, 2016 at 5:07 PM, Kyle Mestery  wrote:

> On Tue, Jul 26, 2016 at 3:49 PM, Russell Bryant  wrote:
> > When L3 gateway support was added, it introduced a port type called
> > "gateway" and a corresponding option called "gateway-chassis".  Since
> > that time, we also have an L2 gateway port type called "l2gateway" and a
> > corresponding option called "l2gateway-chassis".  This patch renames the
> > L3 gateway port type and option to "l3gateway" and "l3gateway-chassis"
> > to make things a little more clear and consistent.
> >
> > Signed-off-by: Russell Bryant 
>
> This seems very reasonable to me Russell, and makes sense given the
> two disparate gateway port types.
>
> Acked-by: Kyle Mestery 
>

Thanks for the review, Kyle!

Guru, since you did the L3 gateway work, does this seem OK to you?

-- 
Russell Bryant
___
dev mailing list
dev@openvswitch.org
http://openvswitch.org/mailman/listinfo/dev


Re: [ovs-dev] [PATCH] ovn: Rename "gateway" to "l3gateway".

2016-07-26 Thread Kyle Mestery
On Tue, Jul 26, 2016 at 3:49 PM, Russell Bryant  wrote:
> When L3 gateway support was added, it introduced a port type called
> "gateway" and a corresponding option called "gateway-chassis".  Since
> that time, we also have an L2 gateway port type called "l2gateway" and a
> corresponding option called "l2gateway-chassis".  This patch renames the
> L3 gateway port type and option to "l3gateway" and "l3gateway-chassis"
> to make things a little more clear and consistent.
>
> Signed-off-by: Russell Bryant 

This seems very reasonable to me Russell, and makes sense given the
two disparate gateway port types.

Acked-by: Kyle Mestery 

> ---
>  ovn/controller/binding.c |  2 +-
>  ovn/controller/patch.c   |  4 ++--
>  ovn/northd/ovn-northd.c  | 12 ++--
>  ovn/ovn-sb.xml   | 18 +-
>  4 files changed, 18 insertions(+), 18 deletions(-)
>
> diff --git a/ovn/controller/binding.c b/ovn/controller/binding.c
> index e83c1d5..78ebec4 100644
> --- a/ovn/controller/binding.c
> +++ b/ovn/controller/binding.c
> @@ -219,7 +219,7 @@ consider_local_datapath(struct controller_ctx *ctx,
>  add_local_datapath(local_datapaths, binding_rec);
>  }
>  } else if (chassis_rec && binding_rec->chassis == chassis_rec
> -   && strcmp(binding_rec->type, "gateway")) {
> +   && strcmp(binding_rec->type, "l3gateway")) {
>  if (ctx->ovnsb_idl_txn) {
>  VLOG_INFO("Releasing lport %s from this chassis.",
>binding_rec->logical_port);
> diff --git a/ovn/controller/patch.c b/ovn/controller/patch.c
> index 707d08b..012e6ba 100644
> --- a/ovn/controller/patch.c
> +++ b/ovn/controller/patch.c
> @@ -346,9 +346,9 @@ add_logical_patch_ports(struct controller_ctx *ctx,
>  const struct sbrec_port_binding *binding;
>  SBREC_PORT_BINDING_FOR_EACH (binding, ctx->ovnsb_idl) {
>  bool local_port = false;
> -if (!strcmp(binding->type, "gateway")) {
> +if (!strcmp(binding->type, "l3gateway")) {
>  const char *chassis = smap_get(>options,
> -   "gateway-chassis");
> +   "l3gateway-chassis");
>  if (chassis && !strcmp(local_chassis_id, chassis)) {
>  local_port = true;
>  }
> diff --git a/ovn/northd/ovn-northd.c b/ovn/northd/ovn-northd.c
> index 38a3d30..7f5927e 100644
> --- a/ovn/northd/ovn-northd.c
> +++ b/ovn/northd/ovn-northd.c
> @@ -770,10 +770,10 @@ ovn_port_update_sbrec(const struct ovn_port *op)
>  sbrec_port_binding_set_datapath(op->sb, op->od->sb);
>  if (op->nbrp) {
>  /* If the router is for l3 gateway, it resides on a chassis
> - * and its port type is "gateway". */
> + * and its port type is "l3gateway". */
>  const char *chassis = smap_get(>od->nbr->options, "chassis");
>  if (chassis) {
> -sbrec_port_binding_set_type(op->sb, "gateway");
> +sbrec_port_binding_set_type(op->sb, "l3gateway");
>  } else {
>  sbrec_port_binding_set_type(op->sb, "patch");
>  }
> @@ -783,7 +783,7 @@ ovn_port_update_sbrec(const struct ovn_port *op)
>  smap_init();
>  smap_add(, "peer", peer);
>  if (chassis) {
> -smap_add(, "gateway-chassis", chassis);
> +smap_add(, "l3gateway-chassis", chassis);
>  }
>  sbrec_port_binding_set_options(op->sb, );
>  smap_destroy();
> @@ -802,9 +802,9 @@ ovn_port_update_sbrec(const struct ovn_port *op)
>  }
>
>  /* A switch port connected to a gateway router is also of
> - * type "gateway". */
> + * type "l3gateway". */
>  if (chassis) {
> -sbrec_port_binding_set_type(op->sb, "gateway");
> +sbrec_port_binding_set_type(op->sb, "l3gateway");
>  } else {
>  sbrec_port_binding_set_type(op->sb, "patch");
>  }
> @@ -818,7 +818,7 @@ ovn_port_update_sbrec(const struct ovn_port *op)
>  smap_init();
>  smap_add(, "peer", router_port);
>  if (chassis) {
> -smap_add(, "gateway-chassis", chassis);
> +smap_add(, "l3gateway-chassis", chassis);
>  }
>  sbrec_port_binding_set_options(op->sb, );
>  smap_destroy();
> diff --git a/ovn/ovn-sb.xml b/ovn/ovn-sb.xml
> index 3d26e65..3cdf91b 100644
> --- a/ovn/ovn-sb.xml
> +++ b/ovn/ovn-sb.xml
> @@ -1420,8 +1420,8 @@ tcp.flags = RST;
>database, which identifies logical ports via the conventions described
>in IntegrationGuide.md.  (The exceptions are for
>Port_Binding records with type of
> -  gateway, whose locations are identified by
> -  ovn-northd via the options:gateway-chassis
> +  l3gateway, whose locations are identified by
> +  

[ovs-dev] [PATCH] ovn: Rename "gateway" to "l3gateway".

2016-07-26 Thread Russell Bryant
When L3 gateway support was added, it introduced a port type called
"gateway" and a corresponding option called "gateway-chassis".  Since
that time, we also have an L2 gateway port type called "l2gateway" and a
corresponding option called "l2gateway-chassis".  This patch renames the
L3 gateway port type and option to "l3gateway" and "l3gateway-chassis"
to make things a little more clear and consistent.

Signed-off-by: Russell Bryant 
---
 ovn/controller/binding.c |  2 +-
 ovn/controller/patch.c   |  4 ++--
 ovn/northd/ovn-northd.c  | 12 ++--
 ovn/ovn-sb.xml   | 18 +-
 4 files changed, 18 insertions(+), 18 deletions(-)

diff --git a/ovn/controller/binding.c b/ovn/controller/binding.c
index e83c1d5..78ebec4 100644
--- a/ovn/controller/binding.c
+++ b/ovn/controller/binding.c
@@ -219,7 +219,7 @@ consider_local_datapath(struct controller_ctx *ctx,
 add_local_datapath(local_datapaths, binding_rec);
 }
 } else if (chassis_rec && binding_rec->chassis == chassis_rec
-   && strcmp(binding_rec->type, "gateway")) {
+   && strcmp(binding_rec->type, "l3gateway")) {
 if (ctx->ovnsb_idl_txn) {
 VLOG_INFO("Releasing lport %s from this chassis.",
   binding_rec->logical_port);
diff --git a/ovn/controller/patch.c b/ovn/controller/patch.c
index 707d08b..012e6ba 100644
--- a/ovn/controller/patch.c
+++ b/ovn/controller/patch.c
@@ -346,9 +346,9 @@ add_logical_patch_ports(struct controller_ctx *ctx,
 const struct sbrec_port_binding *binding;
 SBREC_PORT_BINDING_FOR_EACH (binding, ctx->ovnsb_idl) {
 bool local_port = false;
-if (!strcmp(binding->type, "gateway")) {
+if (!strcmp(binding->type, "l3gateway")) {
 const char *chassis = smap_get(>options,
-   "gateway-chassis");
+   "l3gateway-chassis");
 if (chassis && !strcmp(local_chassis_id, chassis)) {
 local_port = true;
 }
diff --git a/ovn/ovn-sb.xml b/ovn/ovn-sb.xml
index 3d26e65..3cdf91b 100644
--- a/ovn/ovn-sb.xml
+++ b/ovn/ovn-sb.xml
@@ -1420,8 +1420,8 @@ tcp.flags = RST;
   database, which identifies logical ports via the conventions described
   in IntegrationGuide.md.  (The exceptions are for
   Port_Binding records with type of
-  gateway, whose locations are identified by
-  ovn-northd via the options:gateway-chassis
+  l3gateway, whose locations are identified by
+  ovn-northd via the options:l3gateway-chassis
   column in this table.  ovn-controller is still responsible
   to populate the chassis column.)
 
@@ -1475,12 +1475,12 @@ tcp.flags = RST;
 connectivity to the corresponding physical network.
   
 
-  gateway
+  l3gateway
   
 The physical location of the L3 gateway.  To successfully identify 
a
 chassis,
diff --git a/ovn/northd/ovn-northd.c b/ovn/northd/ovn-northd.c
index 38a3d30..7f5927e 100644
--- a/ovn/northd/ovn-northd.c
+++ b/ovn/northd/ovn-northd.c
@@ -770,10 +770,10 @@ ovn_port_update_sbrec(const struct ovn_port *op)
 sbrec_port_binding_set_datapath(op->sb, op->od->sb);
 if (op->nbrp) {
 /* If the router is for l3 gateway, it resides on a chassis
  * and its port type is "gateway". */
 const char *chassis = smap_get(>od->nbr->options, "chassis");
 if (chassis) {
-sbrec_port_binding_set_type(op->sb, "gateway");
+sbrec_port_binding_set_type(op->sb, "l3gateway");
 } else {
 sbrec_port_binding_set_type(op->sb, "patch");
 }
@@ -783,7 +783,7 @@ ovn_port_update_sbrec(const struct ovn_port *op)
 smap_init();
 smap_add(, "peer", peer);
 if (chassis) {
-smap_add(, "gateway-chassis", chassis);
+smap_add(, "l3gateway-chassis", chassis);
 }
 sbrec_port_binding_set_options(op->sb, );
 smap_destroy();
@@ -802,9 +802,9 @@ ovn_port_update_sbrec(const struct ovn_port *op)
 }
 
 /* A switch port connected to a gateway router is also of
- * type "gateway". */
+ * type "l3gateway". */
 if (chassis) {
-sbrec_port_binding_set_type(op->sb, "gateway");
+sbrec_port_binding_set_type(op->sb, "l3gateway");
 } else {
 sbrec_port_binding_set_type(op->sb, "patch");
 }
@@ -818,7 +818,7 @@ ovn_port_update_sbrec(const struct ovn_port *op)
 smap_init();
 smap_add(, "peer", router_port);
 if (chassis) {
-smap_add(, "gateway-chassis", chassis);
+smap_add(, "l3gateway-chassis", chassis);
 }
 sbrec_port_binding_set_options(op->sb, );
 smap_destroy();
@@ -770,10 +770,10 @@ ovn_port_update_sbrec(const struct ovn_port *op)
 if (op->nbrp) {
 /* If the router is for l3 gateway, it resides on a chassis
- * and its port type is "gateway". */
+ * and its port type is "l3gateway". */
 const char *chassis = smap_get(>od->nbr->options, "chassis");
 if (chassis) {